summaryrefslogtreecommitdiff
path: root/TAO
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2006-07-11 01:09:11 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2006-07-11 01:09:11 +0000
commite86aeff1d7f8378f8b5b69b50b82f81a21185cbb (patch)
tree8ff6b2c9ff07a96b91b598337ec4d60df140bec1 /TAO
parentc0ced1006349eb0c918972ae937a0514d667b4f0 (diff)
downloadATCD-e86aeff1d7f8378f8b5b69b50b82f81a21185cbb.tar.gz
ChangeLogTag: Tue Jul 11 00:50:23 2006 Johnny Willemsen <jwillemsen@remedy.nl>
Diffstat (limited to 'TAO')
-rw-r--r--TAO/TAO_IDL/be/be_codegen.cpp69
-rw-r--r--TAO/TAO_IDL/be/be_global.cpp55
-rw-r--r--TAO/TAO_IDL/be_include/be_global.h16
-rw-r--r--TAO/docs/compiler.html18
-rw-r--r--TAO/tao/CodecFactory.mpc8
-rw-r--r--TAO/tao/CodecFactory/IOP_CodecC.cpp1204
-rw-r--r--TAO/tao/CodecFactory/IOP_CodecC.h748
-rw-r--r--TAO/tao/CodecFactory/IOP_CodecS.h28
-rw-r--r--TAO/tao/PI_Server/PortableServer_ORBInitializer.cpp4
-rw-r--r--TAO/tao/PI_Server/PortableServer_PolicyFactory.cpp8
-rw-r--r--TAO/tao/PortableServer/Object_Adapter.cpp2
-rw-r--r--TAO/tao/PortableServer/Root_POA.cpp7
-rw-r--r--TAO/tao/RTCORBA/RT_Invocation_Endpoint_Selectors.cpp6
-rw-r--r--TAO/tao/RTCORBA/RT_Transport_Descriptor.cpp13
14 files changed, 175 insertions, 2011 deletions
diff --git a/TAO/TAO_IDL/be/be_global.cpp b/TAO/TAO_IDL/be/be_global.cpp
index 71a426ce476..b253e889e3e 100644
--- a/TAO/TAO_IDL/be/be_global.cpp
+++ b/TAO/TAO_IDL/be/be_global.cpp
@@ -50,6 +50,8 @@ BE_GlobalData::BE_GlobalData (void)
pch_include_ (0),
pre_include_ (0),
post_include_ (0),
+ include_guard_ (0),
+ safe_include_ (0),
core_versioning_begin_ ("\nTAO_BEGIN_VERSIONED_NAMESPACE_DECL\n"),
core_versioning_end_ ("\nTAO_END_VERSIONED_NAMESPACE_DECL\n"),
versioning_begin_ (),
@@ -576,6 +578,30 @@ BE_GlobalData::post_include (const char *s)
this->post_include_ = ACE_OS::strdup (s);
}
+const char*
+BE_GlobalData::include_guard (void) const
+{
+ return this->include_guard_;
+}
+
+void
+BE_GlobalData::include_guard (const char *s)
+{
+ this->include_guard_ = ACE_OS::strdup (s);
+}
+
+const char*
+BE_GlobalData::safe_include (void) const
+{
+ return this->safe_include_;
+}
+
+void
+BE_GlobalData::safe_include (const char *s)
+{
+ this->safe_include_ = ACE_OS::strdup (s);
+}
+
void
BE_GlobalData::versioning_begin (const char * s)
{
@@ -1100,6 +1126,12 @@ BE_GlobalData::destroy (void)
ACE_OS::free (this->post_include_);
this->post_include_ = 0;
+ ACE_OS::free (this->include_guard_);
+ this->include_guard_ = 0;
+
+ ACE_OS::free (this->safe_include_);
+ this->safe_include_ = 0;
+
delete [] this->client_hdr_ending_;
this->client_hdr_ending_ = 0;
@@ -2079,7 +2111,8 @@ BE_GlobalData::prep_be_arg (char *s)
static const char arg_versioning_begin[] = "versioning_begin=";
static const char arg_versioning_end[] = "versioning_end=";
static const char obv_opt_accessor[] = "obv_opt_accessor";
-
+ static const char include_guard[] = "include_guard=";
+ static const char safe_include[] = "safe_include=";
char* last = 0;
@@ -2144,6 +2177,16 @@ BE_GlobalData::prep_be_arg (char *s)
char* val = arg + sizeof (arg_post_include) - 1;
be_global->post_include (val);
}
+ else if (ACE_OS::strstr (arg, include_guard) == arg)
+ {
+ char* val = arg + sizeof (include_guard) - 1;
+ be_global->include_guard (val);
+ }
+ else if (ACE_OS::strstr (arg, safe_include) == arg)
+ {
+ char* val = arg + sizeof (safe_include) - 1;
+ be_global->safe_include (val);
+ }
else if (ACE_OS::strstr (arg, obv_opt_accessor) == arg)
{
be_global->obv_opt_accessor (1);
@@ -2291,6 +2334,16 @@ BE_GlobalData::usage (void) const
));
ACE_DEBUG ((
LM_DEBUG,
+ ACE_TEXT (" -Wb,include_guard=<include path>\t\tguard to prevent ")
+ ACE_TEXT ("the generated client header file\n")
+ ));
+ ACE_DEBUG ((
+ LM_DEBUG,
+ ACE_TEXT (" -Wb,safe_include=<include path>\t\tinclude that should ")
+ ACE_TEXT ("be used instead of the own generated client header file\n")
+ ));
+ ACE_DEBUG ((
+ LM_DEBUG,
ACE_TEXT (" -Wb,obv_opt_accessor\t\t\t\toptimizes access to base class ")
ACE_TEXT ("data in valuetypes\n")
));
diff --git a/TAO/TAO_IDL/be_include/be_global.h b/TAO/TAO_IDL/be_include/be_global.h
index 515cc017a64..fd766be15fc 100644
--- a/TAO/TAO_IDL/be_include/be_global.h
+++ b/TAO/TAO_IDL/be_include/be_global.h
@@ -209,6 +209,20 @@ public:
// set the name of the include file to be put at the bottom of every
// header file.
+ const char* include_guard (void) const;
+ // returns the guard that is placed in the client header file
+
+ void include_guard (const char* s);
+ // set the guard that is placed in the client header file
+
+ const char* safe_include (void) const;
+ // returns the name of the include file that is used instead of the own
+ // generated client header file
+
+ void safe_include (const char* s);
+ // set the name of the include file that is used instead of the own
+ // generated client header file
+
/// Set text that opens a "versioned" namespace.
void versioning_begin (const char* s);
@@ -558,6 +572,8 @@ private:
char* pch_include_;
char* pre_include_;
char* post_include_;
+ char* include_guard_;
+ char* safe_include_;
/// Text that opens a "versioned" namespace for core TAO and orbsvcs
/// related code.
diff --git a/TAO/docs/compiler.html b/TAO/docs/compiler.html
index eea24b9f783..7877ff7484a 100644
--- a/TAO/docs/compiler.html
+++ b/TAO/docs/compiler.html
@@ -367,6 +367,24 @@ also receives other options that are specific to it.<p>
and CORBA services.</td>
</tr>
+ <tr><a name="include_guard">
+ <td></td>
+
+ <td><tt>include_guard=</tt><i>define</i></td>
+
+ <td>The compiler will generate code the define in the C.h file to prevent
+ users from including the generated C.h file. Useful for regenerating
+ the pidl files in the archive.</td>
+ </tr>
+
+ <tr><a name="safe_include">
+ <td></td>
+
+ <td><tt>safe_include=</tt><i>file</i></td>
+
+ <td>File that the user should include instead of this generated C.h file.
+ Useful for regenerating the pidl files in the archive.</td>
+ </tr>
<tr><a name="E">
<td><tt>-E</tt></td>
diff --git a/TAO/tao/CodecFactory.mpc b/TAO/tao/CodecFactory.mpc
index bce9efe768c..e19070e2433 100644
--- a/TAO/tao/CodecFactory.mpc
+++ b/TAO/tao/CodecFactory.mpc
@@ -28,6 +28,14 @@ project : taolib, core, core_anytypecode, tao_versioning_idl_defaults {
}
IDL_Files {
+ idlflags += -Gp -Gd -Ge 1 -Sci -SS -Sorb -Sal \
+ -Wb,export_macro=TAO_CodecFactory_Export \
+ -Wb,export_include=tao/CodecFactory/codecfactory_export.h \
+ -Wb,include_guard=TAO_CODECFACTORY_SAFE_INCLUDE \
+ -Wb,safe_include=tao/CodecFactory/CodecFactory.h \
+ -o CodecFactory
+ idlflags -= -Sa -St
+ CodecFactory/IOP_Codec.pidl
}
Pkgconfig_Files {
diff --git a/TAO/tao/CodecFactory/IOP_CodecC.cpp b/TAO/tao/CodecFactory/IOP_CodecC.cpp
deleted file mode 100644
index d68677a5975..00000000000
--- a/TAO/tao/CodecFactory/IOP_CodecC.cpp
+++ /dev/null
@@ -1,1204 +0,0 @@
-// -*- C++ -*-
-//
-// $Id$
-
-// **** Code generated by the The ACE ORB (TAO) IDL Compiler ****
-// TAO and the TAO IDL Compiler have been developed by:
-// Center for Distributed Object Computing
-// Washington University
-// St. Louis, MO
-// USA
-// http://www.cs.wustl.edu/~schmidt/doc-center.html
-// and
-// Distributed Object Computing Laboratory
-// University of California at Irvine
-// Irvine, CA
-// USA
-// http://doc.ece.uci.edu/
-// and
-// Institute for Software Integrated Systems
-// Vanderbilt University
-// Nashville, TN
-// USA
-// http://www.isis.vanderbilt.edu/
-//
-// Information about TAO is available at:
-// http://www.cs.wustl.edu/~schmidt/TAO.html
-
-// TAO_IDL - Generated from
-// be\be_codegen.cpp:277
-
-
-#include "tao/CodecFactory/CodecFactory.h"
-#include "tao/AnyTypeCode/Null_RefCount_Policy.h"
-#include "tao/AnyTypeCode/TypeCode_Constants.h"
-#include "tao/AnyTypeCode/Alias_TypeCode_Static.h"
-#include "tao/AnyTypeCode/Objref_TypeCode_Static.h"
-#include "tao/AnyTypeCode/Struct_TypeCode_Static.h"
-#include "tao/AnyTypeCode/TypeCode_Struct_Field.h"
-#include "tao/CDR.h"
-#include "tao/ORB_Core.h"
-#include "tao/AnyTypeCode/Any.h"
-#include "tao/AnyTypeCode/Any_Impl_T.h"
-#include "tao/AnyTypeCode/Any_Dual_Impl_T.h"
-#include "ace/OS_NS_string.h"
-
-// TAO_IDL - Generated from
-// be\be_visitor_arg_traits.cpp:70
-
-TAO_BEGIN_VERSIONED_NAMESPACE_DECL
-
-// Arg traits specializations.
-namespace TAO
-{
-}
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_interface/interface_cs.cpp:60
-
-// Traits specializations for IOP::Codec.
-
-IOP::Codec_ptr
-TAO::Objref_Traits<IOP::Codec>::duplicate (
- IOP::Codec_ptr p
- )
-{
- return IOP::Codec::_duplicate (p);
-}
-
-void
-TAO::Objref_Traits<IOP::Codec>::release (
- IOP::Codec_ptr p
- )
-{
- ::CORBA::release (p);
-}
-
-IOP::Codec_ptr
-TAO::Objref_Traits<IOP::Codec>::nil (void)
-{
- return IOP::Codec::_nil ();
-}
-
-::CORBA::Boolean
-TAO::Objref_Traits<IOP::Codec>::marshal (
- IOP::Codec_ptr p,
- TAO_OutputCDR & cdr
- )
-{
- return ::CORBA::Object::marshal (p, cdr);
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_exception/exception_cs.cpp:63
-
-IOP::Codec::InvalidTypeForEncoding::InvalidTypeForEncoding (void)
- : ::CORBA::UserException (
- "IDL:omg.org/IOP/Codec/InvalidTypeForEncoding:1.0",
- "InvalidTypeForEncoding"
- )
-{
-}
-
-IOP::Codec::InvalidTypeForEncoding::~InvalidTypeForEncoding (void)
-{
-}
-
-IOP::Codec::InvalidTypeForEncoding::InvalidTypeForEncoding (const ::IOP::Codec::InvalidTypeForEncoding &_tao_excp)
- : ::CORBA::UserException (
- _tao_excp._rep_id (),
- _tao_excp._name ()
- )
-{
-}
-
-IOP::Codec::InvalidTypeForEncoding&
-IOP::Codec::InvalidTypeForEncoding::operator= (const ::IOP::Codec::InvalidTypeForEncoding &_tao_excp)
-{
- this->::CORBA::UserException::operator= (_tao_excp);
- return *this;
-}
-
-void IOP::Codec::InvalidTypeForEncoding::_tao_any_destructor (void *_tao_void_pointer)
-{
- InvalidTypeForEncoding *_tao_tmp_pointer =
- static_cast<InvalidTypeForEncoding *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-IOP::Codec::InvalidTypeForEncoding *
-IOP::Codec::InvalidTypeForEncoding::_downcast ( ::CORBA::Exception *_tao_excp)
-{
- return dynamic_cast<InvalidTypeForEncoding *> (_tao_excp);
-}
-
-const IOP::Codec::InvalidTypeForEncoding *
-IOP::Codec::InvalidTypeForEncoding::_downcast ( ::CORBA::Exception const *_tao_excp)
-{
- return dynamic_cast<const InvalidTypeForEncoding *> (_tao_excp);
-}
-
-::CORBA::Exception *IOP::Codec::InvalidTypeForEncoding::_alloc (void)
-{
- ::CORBA::Exception *retval = 0;
- ACE_NEW_RETURN (retval, ::IOP::Codec::InvalidTypeForEncoding, 0);
- return retval;
-}
-
-::CORBA::Exception *
-IOP::Codec::InvalidTypeForEncoding::_tao_duplicate (void) const
-{
- ::CORBA::Exception *result = 0;
- ACE_NEW_RETURN (
- result,
- ::IOP::Codec::InvalidTypeForEncoding (*this),
- 0
- );
- return result;
-}
-
-void IOP::Codec::InvalidTypeForEncoding::_raise (void) const
-{
- TAO_RAISE (*this);
-}
-
-void IOP::Codec::InvalidTypeForEncoding::_tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-void IOP::Codec::InvalidTypeForEncoding::_tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- )
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-// TAO extension - the virtual _type method.
-::CORBA::TypeCode_ptr IOP::Codec::InvalidTypeForEncoding::_tao_type (void) const
-{
- return ::IOP::Codec::_tc_InvalidTypeForEncoding;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const * const _tao_fields_IOP_Codec_InvalidTypeForEncoding = 0;
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_Codec_InvalidTypeForEncoding (
- ::CORBA::tk_except,
- "IDL:omg.org/IOP/Codec/InvalidTypeForEncoding:1.0",
- "InvalidTypeForEncoding",
- _tao_fields_IOP_Codec_InvalidTypeForEncoding,
- 0);
-
-::CORBA::TypeCode_ptr const IOP::Codec::_tc_InvalidTypeForEncoding =
- &_tao_tc_IOP_Codec_InvalidTypeForEncoding;
-
-// TAO_IDL - Generated from
-// be\be_visitor_exception/exception_cs.cpp:63
-
-IOP::Codec::FormatMismatch::FormatMismatch (void)
- : ::CORBA::UserException (
- "IDL:omg.org/IOP/Codec/FormatMismatch:1.0",
- "FormatMismatch"
- )
-{
-}
-
-IOP::Codec::FormatMismatch::~FormatMismatch (void)
-{
-}
-
-IOP::Codec::FormatMismatch::FormatMismatch (const ::IOP::Codec::FormatMismatch &_tao_excp)
- : ::CORBA::UserException (
- _tao_excp._rep_id (),
- _tao_excp._name ()
- )
-{
-}
-
-IOP::Codec::FormatMismatch&
-IOP::Codec::FormatMismatch::operator= (const ::IOP::Codec::FormatMismatch &_tao_excp)
-{
- this->::CORBA::UserException::operator= (_tao_excp);
- return *this;
-}
-
-void IOP::Codec::FormatMismatch::_tao_any_destructor (void *_tao_void_pointer)
-{
- FormatMismatch *_tao_tmp_pointer =
- static_cast<FormatMismatch *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-IOP::Codec::FormatMismatch *
-IOP::Codec::FormatMismatch::_downcast ( ::CORBA::Exception *_tao_excp)
-{
- return dynamic_cast<FormatMismatch *> (_tao_excp);
-}
-
-const IOP::Codec::FormatMismatch *
-IOP::Codec::FormatMismatch::_downcast ( ::CORBA::Exception const *_tao_excp)
-{
- return dynamic_cast<const FormatMismatch *> (_tao_excp);
-}
-
-::CORBA::Exception *IOP::Codec::FormatMismatch::_alloc (void)
-{
- ::CORBA::Exception *retval = 0;
- ACE_NEW_RETURN (retval, ::IOP::Codec::FormatMismatch, 0);
- return retval;
-}
-
-::CORBA::Exception *
-IOP::Codec::FormatMismatch::_tao_duplicate (void) const
-{
- ::CORBA::Exception *result = 0;
- ACE_NEW_RETURN (
- result,
- ::IOP::Codec::FormatMismatch (*this),
- 0
- );
- return result;
-}
-
-void IOP::Codec::FormatMismatch::_raise (void) const
-{
- TAO_RAISE (*this);
-}
-
-void IOP::Codec::FormatMismatch::_tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-void IOP::Codec::FormatMismatch::_tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- )
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-// TAO extension - the virtual _type method.
-::CORBA::TypeCode_ptr IOP::Codec::FormatMismatch::_tao_type (void) const
-{
- return ::IOP::Codec::_tc_FormatMismatch;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const * const _tao_fields_IOP_Codec_FormatMismatch = 0;
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_Codec_FormatMismatch (
- ::CORBA::tk_except,
- "IDL:omg.org/IOP/Codec/FormatMismatch:1.0",
- "FormatMismatch",
- _tao_fields_IOP_Codec_FormatMismatch,
- 0);
-
-::CORBA::TypeCode_ptr const IOP::Codec::_tc_FormatMismatch =
- &_tao_tc_IOP_Codec_FormatMismatch;
-
-// TAO_IDL - Generated from
-// be\be_visitor_exception/exception_cs.cpp:63
-
-IOP::Codec::TypeMismatch::TypeMismatch (void)
- : ::CORBA::UserException (
- "IDL:omg.org/IOP/Codec/TypeMismatch:1.0",
- "TypeMismatch"
- )
-{
-}
-
-IOP::Codec::TypeMismatch::~TypeMismatch (void)
-{
-}
-
-IOP::Codec::TypeMismatch::TypeMismatch (const ::IOP::Codec::TypeMismatch &_tao_excp)
- : ::CORBA::UserException (
- _tao_excp._rep_id (),
- _tao_excp._name ()
- )
-{
-}
-
-IOP::Codec::TypeMismatch&
-IOP::Codec::TypeMismatch::operator= (const ::IOP::Codec::TypeMismatch &_tao_excp)
-{
- this->::CORBA::UserException::operator= (_tao_excp);
- return *this;
-}
-
-void IOP::Codec::TypeMismatch::_tao_any_destructor (void *_tao_void_pointer)
-{
- TypeMismatch *_tao_tmp_pointer =
- static_cast<TypeMismatch *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-IOP::Codec::TypeMismatch *
-IOP::Codec::TypeMismatch::_downcast ( ::CORBA::Exception *_tao_excp)
-{
- return dynamic_cast<TypeMismatch *> (_tao_excp);
-}
-
-const IOP::Codec::TypeMismatch *
-IOP::Codec::TypeMismatch::_downcast ( ::CORBA::Exception const *_tao_excp)
-{
- return dynamic_cast<const TypeMismatch *> (_tao_excp);
-}
-
-::CORBA::Exception *IOP::Codec::TypeMismatch::_alloc (void)
-{
- ::CORBA::Exception *retval = 0;
- ACE_NEW_RETURN (retval, ::IOP::Codec::TypeMismatch, 0);
- return retval;
-}
-
-::CORBA::Exception *
-IOP::Codec::TypeMismatch::_tao_duplicate (void) const
-{
- ::CORBA::Exception *result = 0;
- ACE_NEW_RETURN (
- result,
- ::IOP::Codec::TypeMismatch (*this),
- 0
- );
- return result;
-}
-
-void IOP::Codec::TypeMismatch::_raise (void) const
-{
- TAO_RAISE (*this);
-}
-
-void IOP::Codec::TypeMismatch::_tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-void IOP::Codec::TypeMismatch::_tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- )
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-// TAO extension - the virtual _type method.
-::CORBA::TypeCode_ptr IOP::Codec::TypeMismatch::_tao_type (void) const
-{
- return ::IOP::Codec::_tc_TypeMismatch;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const * const _tao_fields_IOP_Codec_TypeMismatch = 0;
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_Codec_TypeMismatch (
- ::CORBA::tk_except,
- "IDL:omg.org/IOP/Codec/TypeMismatch:1.0",
- "TypeMismatch",
- _tao_fields_IOP_Codec_TypeMismatch,
- 0);
-
-::CORBA::TypeCode_ptr const IOP::Codec::_tc_TypeMismatch =
- &_tao_tc_IOP_Codec_TypeMismatch;
-
-IOP::Codec::Codec (void)
-{}
-
-IOP::Codec::~Codec (void)
-{}
-
-IOP::Codec_ptr
-IOP::Codec::_narrow (
- ::CORBA::Object_ptr _tao_objref
- ACE_ENV_ARG_DECL_NOT_USED
- )
-{
- return Codec::_duplicate (
- dynamic_cast<Codec_ptr> (_tao_objref)
- );
-}
-
-IOP::Codec_ptr
-IOP::Codec::_unchecked_narrow (
- ::CORBA::Object_ptr _tao_objref
- ACE_ENV_ARG_DECL_NOT_USED
- )
-{
- return Codec::_duplicate (
- dynamic_cast<Codec_ptr> (_tao_objref)
- );
-}
-
-IOP::Codec_ptr
-IOP::Codec::_duplicate (Codec_ptr obj)
-{
- if (! ::CORBA::is_nil (obj))
- {
- obj->_add_ref ();
- }
-
- return obj;
-}
-
-void
-IOP::Codec::_tao_release (Codec_ptr obj)
-{
- ::CORBA::release (obj);
-}
-
-::CORBA::Boolean
-IOP::Codec::_is_a (
- const char *value
- ACE_ENV_ARG_DECL_NOT_USED
- )
-{
- if (
- !ACE_OS::strcmp (
- value,
- "IDL:omg.org/IOP/Codec:1.0"
- ) ||
- !ACE_OS::strcmp (
- value,
- "IDL:omg.org/CORBA/LocalObject:1.0"
- ) ||
- !ACE_OS::strcmp (
- value,
- "IDL:omg.org/CORBA/Object:1.0"
- )
- )
- {
- return true; // success using local knowledge
- }
- else
- {
- return false;
- }
-}
-
-const char* IOP::Codec::_interface_repository_id (void) const
-{
- return "IDL:omg.org/IOP/Codec:1.0";
-}
-
-::CORBA::Boolean
-IOP::Codec::marshal (TAO_OutputCDR &)
-{
- return false;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/objref_typecode.cpp:76
-
-static TAO::TypeCode::Objref<char const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_Codec (
- ::CORBA::tk_local_interface,
- "IDL:omg.org/IOP/Codec:1.0",
- "Codec");
-
-namespace IOP
-{
- ::CORBA::TypeCode_ptr const _tc_Codec =
- &_tao_tc_IOP_Codec;
-}
-
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:50
-
-static TAO::TypeCode::Alias<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_EncodingFormat (
- ::CORBA::tk_alias,
- "IDL:omg.org/IOP/EncodingFormat:1.0",
- "EncodingFormat",
- &CORBA::_tc_short);
-
-namespace IOP
-{
- ::CORBA::TypeCode_ptr const _tc_EncodingFormat =
- &_tao_tc_IOP_EncodingFormat;
-}
-
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const _tao_fields_IOP_Encoding[] =
- {
- { "format", &IOP::_tc_EncodingFormat },
- { "major_version", &CORBA::_tc_octet },
- { "minor_version", &CORBA::_tc_octet }
-
- };
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_Encoding (
- ::CORBA::tk_struct,
- "IDL:omg.org/IOP/Encoding:1.0",
- "Encoding",
- _tao_fields_IOP_Encoding,
- 3);
-
-namespace IOP
-{
- ::CORBA::TypeCode_ptr const _tc_Encoding =
- &_tao_tc_IOP_Encoding;
-}
-
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/structure_cs.cpp:66
-
-void
-IOP::Encoding::_tao_any_destructor (
- void *_tao_void_pointer
- )
-{
- Encoding *_tao_tmp_pointer =
- static_cast<Encoding *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const _tao_fields_IOP_Encoding_1_2[] =
- {
- { "format", &IOP::_tc_EncodingFormat },
- { "major_version", &CORBA::_tc_octet },
- { "minor_version", &CORBA::_tc_octet },
- { "char_codeset", &CONV_FRAME::_tc_CodeSetId },
- { "wchar_codeset", &CONV_FRAME::_tc_CodeSetId }
-
- };
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_Encoding_1_2 (
- ::CORBA::tk_struct,
- "IDL:omg.org/IOP/Encoding_1_2:1.0",
- "Encoding_1_2",
- _tao_fields_IOP_Encoding_1_2,
- 5);
-
-namespace IOP
-{
- ::CORBA::TypeCode_ptr const _tc_Encoding_1_2 =
- &_tao_tc_IOP_Encoding_1_2;
-}
-
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/structure_cs.cpp:66
-
-void
-IOP::Encoding_1_2::_tao_any_destructor (
- void *_tao_void_pointer
- )
-{
- Encoding_1_2 *_tao_tmp_pointer =
- static_cast<Encoding_1_2 *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_interface/interface_cs.cpp:60
-
-// Traits specializations for IOP::CodecFactory.
-
-IOP::CodecFactory_ptr
-TAO::Objref_Traits<IOP::CodecFactory>::duplicate (
- IOP::CodecFactory_ptr p
- )
-{
- return IOP::CodecFactory::_duplicate (p);
-}
-
-void
-TAO::Objref_Traits<IOP::CodecFactory>::release (
- IOP::CodecFactory_ptr p
- )
-{
- ::CORBA::release (p);
-}
-
-IOP::CodecFactory_ptr
-TAO::Objref_Traits<IOP::CodecFactory>::nil (void)
-{
- return IOP::CodecFactory::_nil ();
-}
-
-::CORBA::Boolean
-TAO::Objref_Traits<IOP::CodecFactory>::marshal (
- IOP::CodecFactory_ptr p,
- TAO_OutputCDR & cdr
- )
-{
- return ::CORBA::Object::marshal (p, cdr);
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_exception/exception_cs.cpp:63
-
-IOP::CodecFactory::UnknownEncoding::UnknownEncoding (void)
- : ::CORBA::UserException (
- "IDL:omg.org/IOP/CodecFactory/UnknownEncoding:1.0",
- "UnknownEncoding"
- )
-{
-}
-
-IOP::CodecFactory::UnknownEncoding::~UnknownEncoding (void)
-{
-}
-
-IOP::CodecFactory::UnknownEncoding::UnknownEncoding (const ::IOP::CodecFactory::UnknownEncoding &_tao_excp)
- : ::CORBA::UserException (
- _tao_excp._rep_id (),
- _tao_excp._name ()
- )
-{
-}
-
-IOP::CodecFactory::UnknownEncoding&
-IOP::CodecFactory::UnknownEncoding::operator= (const ::IOP::CodecFactory::UnknownEncoding &_tao_excp)
-{
- this->::CORBA::UserException::operator= (_tao_excp);
- return *this;
-}
-
-void IOP::CodecFactory::UnknownEncoding::_tao_any_destructor (void *_tao_void_pointer)
-{
- UnknownEncoding *_tao_tmp_pointer =
- static_cast<UnknownEncoding *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-IOP::CodecFactory::UnknownEncoding *
-IOP::CodecFactory::UnknownEncoding::_downcast ( ::CORBA::Exception *_tao_excp)
-{
- return dynamic_cast<UnknownEncoding *> (_tao_excp);
-}
-
-const IOP::CodecFactory::UnknownEncoding *
-IOP::CodecFactory::UnknownEncoding::_downcast ( ::CORBA::Exception const *_tao_excp)
-{
- return dynamic_cast<const UnknownEncoding *> (_tao_excp);
-}
-
-::CORBA::Exception *IOP::CodecFactory::UnknownEncoding::_alloc (void)
-{
- ::CORBA::Exception *retval = 0;
- ACE_NEW_RETURN (retval, ::IOP::CodecFactory::UnknownEncoding, 0);
- return retval;
-}
-
-::CORBA::Exception *
-IOP::CodecFactory::UnknownEncoding::_tao_duplicate (void) const
-{
- ::CORBA::Exception *result = 0;
- ACE_NEW_RETURN (
- result,
- ::IOP::CodecFactory::UnknownEncoding (*this),
- 0
- );
- return result;
-}
-
-void IOP::CodecFactory::UnknownEncoding::_raise (void) const
-{
- TAO_RAISE (*this);
-}
-
-void IOP::CodecFactory::UnknownEncoding::_tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-void IOP::CodecFactory::UnknownEncoding::_tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- )
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-// TAO extension - the virtual _type method.
-::CORBA::TypeCode_ptr IOP::CodecFactory::UnknownEncoding::_tao_type (void) const
-{
- return ::IOP::CodecFactory::_tc_UnknownEncoding;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const * const _tao_fields_IOP_CodecFactory_UnknownEncoding = 0;
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_CodecFactory_UnknownEncoding (
- ::CORBA::tk_except,
- "IDL:omg.org/IOP/CodecFactory/UnknownEncoding:1.0",
- "UnknownEncoding",
- _tao_fields_IOP_CodecFactory_UnknownEncoding,
- 0);
-
-::CORBA::TypeCode_ptr const IOP::CodecFactory::_tc_UnknownEncoding =
- &_tao_tc_IOP_CodecFactory_UnknownEncoding;
-
-// TAO_IDL - Generated from
-// be\be_visitor_exception/exception_cs.cpp:63
-
-IOP::CodecFactory::UnsupportedCodeset::UnsupportedCodeset (void)
- : ::CORBA::UserException (
- "IDL:omg.org/IOP/CodecFactory/UnsupportedCodeset:1.0",
- "UnsupportedCodeset"
- )
-{
-}
-
-IOP::CodecFactory::UnsupportedCodeset::~UnsupportedCodeset (void)
-{
-}
-
-IOP::CodecFactory::UnsupportedCodeset::UnsupportedCodeset (const ::IOP::CodecFactory::UnsupportedCodeset &_tao_excp)
- : ::CORBA::UserException (
- _tao_excp._rep_id (),
- _tao_excp._name ()
- )
-{
- this->codeset = _tao_excp.codeset;
-}
-
-IOP::CodecFactory::UnsupportedCodeset&
-IOP::CodecFactory::UnsupportedCodeset::operator= (const ::IOP::CodecFactory::UnsupportedCodeset &_tao_excp)
-{
- this->::CORBA::UserException::operator= (_tao_excp);
- this->codeset = _tao_excp.codeset;
- return *this;
-}
-
-void IOP::CodecFactory::UnsupportedCodeset::_tao_any_destructor (void *_tao_void_pointer)
-{
- UnsupportedCodeset *_tao_tmp_pointer =
- static_cast<UnsupportedCodeset *> (_tao_void_pointer);
- delete _tao_tmp_pointer;
-}
-
-IOP::CodecFactory::UnsupportedCodeset *
-IOP::CodecFactory::UnsupportedCodeset::_downcast ( ::CORBA::Exception *_tao_excp)
-{
- return dynamic_cast<UnsupportedCodeset *> (_tao_excp);
-}
-
-const IOP::CodecFactory::UnsupportedCodeset *
-IOP::CodecFactory::UnsupportedCodeset::_downcast ( ::CORBA::Exception const *_tao_excp)
-{
- return dynamic_cast<const UnsupportedCodeset *> (_tao_excp);
-}
-
-::CORBA::Exception *IOP::CodecFactory::UnsupportedCodeset::_alloc (void)
-{
- ::CORBA::Exception *retval = 0;
- ACE_NEW_RETURN (retval, ::IOP::CodecFactory::UnsupportedCodeset, 0);
- return retval;
-}
-
-::CORBA::Exception *
-IOP::CodecFactory::UnsupportedCodeset::_tao_duplicate (void) const
-{
- ::CORBA::Exception *result = 0;
- ACE_NEW_RETURN (
- result,
- ::IOP::CodecFactory::UnsupportedCodeset (*this),
- 0
- );
- return result;
-}
-
-void IOP::CodecFactory::UnsupportedCodeset::_raise (void) const
-{
- TAO_RAISE (*this);
-}
-
-void IOP::CodecFactory::UnsupportedCodeset::_tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-void IOP::CodecFactory::UnsupportedCodeset::_tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- )
-{
- ACE_THROW ( ::CORBA::MARSHAL ());
-}
-
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_exception/exception_ctor.cpp:66
-
-IOP::CodecFactory::UnsupportedCodeset::UnsupportedCodeset (
- ::CONV_FRAME::CodeSetId _tao_codeset
- )
- : ::CORBA::UserException (
- "IDL:omg.org/IOP/CodecFactory/UnsupportedCodeset:1.0",
- "UnsupportedCodeset"
- )
-{
- this->codeset = _tao_codeset;
-}
-
-// TAO extension - the virtual _type method.
-::CORBA::TypeCode_ptr IOP::CodecFactory::UnsupportedCodeset::_tao_type (void) const
-{
- return ::IOP::CodecFactory::_tc_UnsupportedCodeset;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/struct_typecode.cpp:89
-
-static TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const _tao_fields_IOP_CodecFactory_UnsupportedCodeset[] =
- {
- { "codeset", &CONV_FRAME::_tc_CodeSetId }
-
- };
-static TAO::TypeCode::Struct<char const *,
- ::CORBA::TypeCode_ptr const *,
- TAO::TypeCode::Struct_Field<char const *, ::CORBA::TypeCode_ptr const *> const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_CodecFactory_UnsupportedCodeset (
- ::CORBA::tk_except,
- "IDL:omg.org/IOP/CodecFactory/UnsupportedCodeset:1.0",
- "UnsupportedCodeset",
- _tao_fields_IOP_CodecFactory_UnsupportedCodeset,
- 1);
-
-::CORBA::TypeCode_ptr const IOP::CodecFactory::_tc_UnsupportedCodeset =
- &_tao_tc_IOP_CodecFactory_UnsupportedCodeset;
-
-IOP::CodecFactory::CodecFactory (void)
-{}
-
-IOP::CodecFactory::~CodecFactory (void)
-{}
-
-IOP::CodecFactory_ptr
-IOP::CodecFactory::_narrow (
- ::CORBA::Object_ptr _tao_objref
- ACE_ENV_ARG_DECL_NOT_USED
- )
-{
- return CodecFactory::_duplicate (
- dynamic_cast<CodecFactory_ptr> (_tao_objref)
- );
-}
-
-IOP::CodecFactory_ptr
-IOP::CodecFactory::_unchecked_narrow (
- ::CORBA::Object_ptr _tao_objref
- ACE_ENV_ARG_DECL_NOT_USED
- )
-{
- return CodecFactory::_duplicate (
- dynamic_cast<CodecFactory_ptr> (_tao_objref)
- );
-}
-
-IOP::CodecFactory_ptr
-IOP::CodecFactory::_duplicate (CodecFactory_ptr obj)
-{
- if (! ::CORBA::is_nil (obj))
- {
- obj->_add_ref ();
- }
-
- return obj;
-}
-
-void
-IOP::CodecFactory::_tao_release (CodecFactory_ptr obj)
-{
- ::CORBA::release (obj);
-}
-
-::CORBA::Boolean
-IOP::CodecFactory::_is_a (
- const char *value
- ACE_ENV_ARG_DECL_NOT_USED
- )
-{
- if (
- !ACE_OS::strcmp (
- value,
- "IDL:omg.org/IOP/CodecFactory:1.0"
- ) ||
- !ACE_OS::strcmp (
- value,
- "IDL:omg.org/CORBA/LocalObject:1.0"
- ) ||
- !ACE_OS::strcmp (
- value,
- "IDL:omg.org/CORBA/Object:1.0"
- )
- )
- {
- return true; // success using local knowledge
- }
- else
- {
- return false;
- }
-}
-
-const char* IOP::CodecFactory::_interface_repository_id (void) const
-{
- return "IDL:omg.org/IOP/CodecFactory:1.0";
-}
-
-::CORBA::Boolean
-IOP::CodecFactory::marshal (TAO_OutputCDR &)
-{
- return false;
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_typecode/objref_typecode.cpp:76
-
-static TAO::TypeCode::Objref<char const *,
- TAO::Null_RefCount_Policy>
- _tao_tc_IOP_CodecFactory (
- ::CORBA::tk_local_interface,
- "IDL:omg.org/IOP/CodecFactory:1.0",
- "CodecFactory");
-
-namespace IOP
-{
- ::CORBA::TypeCode_ptr const _tc_CodecFactory =
- &_tao_tc_IOP_CodecFactory;
-}
-
-
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/any_op_cs.cpp:54
-
-// Copying insertion.
-void operator<<= (
- ::CORBA::Any &_tao_any,
- const IOP::Encoding &_tao_elem
- )
-{
- if (0 == &_tao_elem) // Trying to de-reference NULL object
- _tao_any <<= static_cast<IOP::Encoding *>( 0 ); // Use non-copying insertion of a NULL
- else
- TAO::Any_Dual_Impl_T<IOP::Encoding>::insert_copy (
- _tao_any,
- IOP::Encoding::_tao_any_destructor,
- IOP::_tc_Encoding,
- _tao_elem
- );
-}
-
-// Non-copying insertion.
-void operator<<= (
- ::CORBA::Any &_tao_any,
- IOP::Encoding *_tao_elem
- )
-{
- TAO::Any_Dual_Impl_T<IOP::Encoding>::insert (
- _tao_any,
- IOP::Encoding::_tao_any_destructor,
- IOP::_tc_Encoding,
- _tao_elem
- );
-}
-
-// Extraction to non-const pointer (deprecated).
-::CORBA::Boolean operator>>= (
- const ::CORBA::Any &_tao_any,
- IOP::Encoding *&_tao_elem
- )
-{
- return _tao_any >>= const_cast<
- const IOP::Encoding *&> (
- _tao_elem
- );
-}
-
-// Extraction to const pointer.
-::CORBA::Boolean operator>>= (
- const ::CORBA::Any &_tao_any,
- const IOP::Encoding *&_tao_elem
- )
-{
- return
- TAO::Any_Dual_Impl_T<IOP::Encoding>::extract (
- _tao_any,
- IOP::Encoding::_tao_any_destructor,
- IOP::_tc_Encoding,
- _tao_elem
- );
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/any_op_cs.cpp:54
-
-// Copying insertion.
-void operator<<= (
- ::CORBA::Any &_tao_any,
- const IOP::Encoding_1_2 &_tao_elem
- )
-{
- if (0 == &_tao_elem) // Trying to de-reference NULL object
- _tao_any <<= static_cast<IOP::Encoding_1_2 *>( 0 ); // Use non-copying insertion of a NULL
- else
- TAO::Any_Dual_Impl_T<IOP::Encoding_1_2>::insert_copy (
- _tao_any,
- IOP::Encoding_1_2::_tao_any_destructor,
- IOP::_tc_Encoding_1_2,
- _tao_elem
- );
-}
-
-// Non-copying insertion.
-void operator<<= (
- ::CORBA::Any &_tao_any,
- IOP::Encoding_1_2 *_tao_elem
- )
-{
- TAO::Any_Dual_Impl_T<IOP::Encoding_1_2>::insert (
- _tao_any,
- IOP::Encoding_1_2::_tao_any_destructor,
- IOP::_tc_Encoding_1_2,
- _tao_elem
- );
-}
-
-// Extraction to non-const pointer (deprecated).
-::CORBA::Boolean operator>>= (
- const ::CORBA::Any &_tao_any,
- IOP::Encoding_1_2 *&_tao_elem
- )
-{
- return _tao_any >>= const_cast<
- const IOP::Encoding_1_2 *&> (
- _tao_elem
- );
-}
-
-// Extraction to const pointer.
-::CORBA::Boolean operator>>= (
- const ::CORBA::Any &_tao_any,
- const IOP::Encoding_1_2 *&_tao_elem
- )
-{
- return
- TAO::Any_Dual_Impl_T<IOP::Encoding_1_2>::extract (
- _tao_any,
- IOP::Encoding_1_2::_tao_any_destructor,
- IOP::_tc_Encoding_1_2,
- _tao_elem
- );
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/cdr_op_cs.cpp:61
-
-::CORBA::Boolean operator<< (
- TAO_OutputCDR &strm,
- const IOP::Encoding &_tao_aggregate
- )
-{
- return
- (strm << _tao_aggregate.format) &&
- (strm << ::ACE_OutputCDR::from_octet (_tao_aggregate.major_version)) &&
- (strm << ::ACE_OutputCDR::from_octet (_tao_aggregate.minor_version));
-}
-
-::CORBA::Boolean operator>> (
- TAO_InputCDR &strm,
- IOP::Encoding &_tao_aggregate
- )
-{
- return
- (strm >> _tao_aggregate.format) &&
- (strm >> ::ACE_InputCDR::to_octet (_tao_aggregate.major_version)) &&
- (strm >> ::ACE_InputCDR::to_octet (_tao_aggregate.minor_version));
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/cdr_op_cs.cpp:61
-
-::CORBA::Boolean operator<< (
- TAO_OutputCDR &strm,
- const IOP::Encoding_1_2 &_tao_aggregate
- )
-{
- return
- (strm << _tao_aggregate.format) &&
- (strm << ::ACE_OutputCDR::from_octet (_tao_aggregate.major_version)) &&
- (strm << ::ACE_OutputCDR::from_octet (_tao_aggregate.minor_version)) &&
- (strm << _tao_aggregate.char_codeset) &&
- (strm << _tao_aggregate.wchar_codeset);
-}
-
-::CORBA::Boolean operator>> (
- TAO_InputCDR &strm,
- IOP::Encoding_1_2 &_tao_aggregate
- )
-{
- return
- (strm >> _tao_aggregate.format) &&
- (strm >> ::ACE_InputCDR::to_octet (_tao_aggregate.major_version)) &&
- (strm >> ::ACE_InputCDR::to_octet (_tao_aggregate.minor_version)) &&
- (strm >> _tao_aggregate.char_codeset) &&
- (strm >> _tao_aggregate.wchar_codeset);
-}
-
-TAO_END_VERSIONED_NAMESPACE_DECL
diff --git a/TAO/tao/CodecFactory/IOP_CodecC.h b/TAO/tao/CodecFactory/IOP_CodecC.h
deleted file mode 100644
index d8d3679abf0..00000000000
--- a/TAO/tao/CodecFactory/IOP_CodecC.h
+++ /dev/null
@@ -1,748 +0,0 @@
-// -*- C++ -*-
-//
-// $Id$
-
-// **** Code generated by the The ACE ORB (TAO) IDL Compiler ****
-// TAO and the TAO IDL Compiler have been developed by:
-// Center for Distributed Object Computing
-// Washington University
-// St. Louis, MO
-// USA
-// http://www.cs.wustl.edu/~schmidt/doc-center.html
-// and
-// Distributed Object Computing Laboratory
-// University of California at Irvine
-// Irvine, CA
-// USA
-// http://doc.ece.uci.edu/
-// and
-// Institute for Software Integrated Systems
-// Vanderbilt University
-// Nashville, TN
-// USA
-// http://www.isis.vanderbilt.edu/
-//
-// Information about TAO is available at:
-// http://www.cs.wustl.edu/~schmidt/TAO.html
-
-// TAO_IDL - Generated from
-// be\be_codegen.cpp:154
-
-#ifndef _TAO_IDL_ORIG_IOP_CODECC_H_
-#define _TAO_IDL_ORIG_IOP_CODECC_H_
-
-#include /**/ "ace/pre.h"
-
-#ifndef TAO_CODECFACTORY_SAFE_INCLUDE
-#error "You should not include IOP_CodecC.h directly, use CodecFactory.h"
-#endif /* !TAO_CODECFACTORY_SAFE_INCLUDE */
-
-#include "ace/config-all.h"
-
-#if !defined (ACE_LACKS_PRAGMA_ONCE)
-# pragma once
-#endif /* ACE_LACKS_PRAGMA_ONCE */
-
-#include "tao/CodecFactory/codecfactory_export.h"
-#include "tao/AnyTypeCode/AnyTypeCode_methods.h"
-#include "tao/ORB.h"
-#include "tao/SystemException.h"
-#include "tao/Environment.h"
-#include "tao/Object.h"
-#include "tao/AnyTypeCode/TypeCode.h"
-#include "tao/AnyTypeCode/TypeCode_Constants.h"
-#include "tao/AnyTypeCode/Any.h"
-#include "tao/AnyTypeCode/Typecode_typesA.h"
-#include "tao/AnyTypeCode/OctetSeqA.h"
-#include "tao/AnyTypeCode/CONV_FRAMEA.h"
-#include "tao/Objref_VarOut_T.h"
-#include "tao/VarOut_T.h"
-
-#include "tao/Typecode_typesC.h"
-#include "tao/OctetSeqC.h"
-#include "tao/CONV_FRAMEC.h"
-
-#if defined (TAO_EXPORT_MACRO)
-#undef TAO_EXPORT_MACRO
-#endif
-#define TAO_EXPORT_MACRO TAO_CodecFactory_Export
-
-// TAO_IDL - Generated from
-// be\be_visitor_module/module_ch.cpp:49
-
-TAO_BEGIN_VERSIONED_NAMESPACE_DECL
-
-namespace IOP
-{
-
- // TAO_IDL - Generated from
- // be\be_interface.cpp:646
-
-#if !defined (_IOP_CODEC__VAR_OUT_CH_)
-#define _IOP_CODEC__VAR_OUT_CH_
-
- class Codec;
- typedef Codec *Codec_ptr;
-
- typedef
- TAO_Objref_Var_T<
- Codec
- >
- Codec_var;
-
- typedef
- TAO_Objref_Out_T<
- Codec
- >
- Codec_out;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_interface/interface_ch.cpp:54
-
-#if !defined (_IOP_CODEC_CH_)
-#define _IOP_CODEC_CH_
-
- class TAO_CodecFactory_Export Codec
- : public virtual ::CORBA::Object
- {
- public:
- typedef Codec_ptr _ptr_type;
- typedef Codec_var _var_type;
-
- // The static operations.
- static Codec_ptr _duplicate (Codec_ptr obj);
-
- static void _tao_release (Codec_ptr obj);
-
- static Codec_ptr _narrow (
- ::CORBA::Object_ptr obj
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- );
-
- static Codec_ptr _unchecked_narrow (
- ::CORBA::Object_ptr obj
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- );
-
- static Codec_ptr _nil (void)
- {
- return static_cast<Codec_ptr> (0);
- }
-
-
-
- // TAO_IDL - Generated from
- // be\be_visitor_exception/exception_ch.cpp:53
-
-#if !defined (_IOP_CODEC_INVALIDTYPEFORENCODING_CH_)
-#define _IOP_CODEC_INVALIDTYPEFORENCODING_CH_
-
- class TAO_CodecFactory_Export InvalidTypeForEncoding : public ::CORBA::UserException
- {
- public:
-
- InvalidTypeForEncoding (void);
- InvalidTypeForEncoding (const InvalidTypeForEncoding &);
- ~InvalidTypeForEncoding (void);
-
- InvalidTypeForEncoding &operator= (const InvalidTypeForEncoding &);
-
- static void _tao_any_destructor (void *);
-
- static InvalidTypeForEncoding *_downcast ( ::CORBA::Exception *);
- static const InvalidTypeForEncoding *_downcast ( ::CORBA::Exception const *);
-
- static ::CORBA::Exception *_alloc (void);
-
- virtual ::CORBA::Exception *_tao_duplicate (void) const;
-
- virtual void _raise (void) const;
-
- virtual void _tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const;
-
- virtual void _tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- );
-
- virtual ::CORBA::TypeCode_ptr _tao_type (void) const;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- static ::CORBA::TypeCode_ptr const _tc_InvalidTypeForEncoding;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_exception/exception_ch.cpp:53
-
-#if !defined (_IOP_CODEC_FORMATMISMATCH_CH_)
-#define _IOP_CODEC_FORMATMISMATCH_CH_
-
- class TAO_CodecFactory_Export FormatMismatch : public ::CORBA::UserException
- {
- public:
-
- FormatMismatch (void);
- FormatMismatch (const FormatMismatch &);
- ~FormatMismatch (void);
-
- FormatMismatch &operator= (const FormatMismatch &);
-
- static void _tao_any_destructor (void *);
-
- static FormatMismatch *_downcast ( ::CORBA::Exception *);
- static const FormatMismatch *_downcast ( ::CORBA::Exception const *);
-
- static ::CORBA::Exception *_alloc (void);
-
- virtual ::CORBA::Exception *_tao_duplicate (void) const;
-
- virtual void _raise (void) const;
-
- virtual void _tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const;
-
- virtual void _tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- );
-
- virtual ::CORBA::TypeCode_ptr _tao_type (void) const;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- static ::CORBA::TypeCode_ptr const _tc_FormatMismatch;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_exception/exception_ch.cpp:53
-
-#if !defined (_IOP_CODEC_TYPEMISMATCH_CH_)
-#define _IOP_CODEC_TYPEMISMATCH_CH_
-
- class TAO_CodecFactory_Export TypeMismatch : public ::CORBA::UserException
- {
- public:
-
- TypeMismatch (void);
- TypeMismatch (const TypeMismatch &);
- ~TypeMismatch (void);
-
- TypeMismatch &operator= (const TypeMismatch &);
-
- static void _tao_any_destructor (void *);
-
- static TypeMismatch *_downcast ( ::CORBA::Exception *);
- static const TypeMismatch *_downcast ( ::CORBA::Exception const *);
-
- static ::CORBA::Exception *_alloc (void);
-
- virtual ::CORBA::Exception *_tao_duplicate (void) const;
-
- virtual void _raise (void) const;
-
- virtual void _tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const;
-
- virtual void _tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- );
-
- virtual ::CORBA::TypeCode_ptr _tao_type (void) const;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- static ::CORBA::TypeCode_ptr const _tc_TypeMismatch;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_operation/operation_ch.cpp:46
-
- virtual ::CORBA::OctetSeq * encode (
- const ::CORBA::Any & data
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- )
- ACE_THROW_SPEC ((
- ::CORBA::SystemException,
- ::IOP::Codec::InvalidTypeForEncoding
- )) = 0;
-
- // TAO_IDL - Generated from
- // be\be_visitor_operation/operation_ch.cpp:46
-
- virtual ::CORBA::Any * decode (
- const ::CORBA::OctetSeq & data
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- )
- ACE_THROW_SPEC ((
- ::CORBA::SystemException,
- ::IOP::Codec::FormatMismatch
- )) = 0;
-
- // TAO_IDL - Generated from
- // be\be_visitor_operation/operation_ch.cpp:46
-
- virtual ::CORBA::OctetSeq * encode_value (
- const ::CORBA::Any & data
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- )
- ACE_THROW_SPEC ((
- ::CORBA::SystemException,
- ::IOP::Codec::InvalidTypeForEncoding
- )) = 0;
-
- // TAO_IDL - Generated from
- // be\be_visitor_operation/operation_ch.cpp:46
-
- virtual ::CORBA::Any * decode_value (
- const ::CORBA::OctetSeq & data,
- ::CORBA::TypeCode_ptr tc
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- )
- ACE_THROW_SPEC ((
- ::CORBA::SystemException,
- ::IOP::Codec::FormatMismatch,
- ::IOP::Codec::TypeMismatch
- )) = 0;
-
- // TAO_IDL - Generated from
- // be\be_visitor_interface/interface_ch.cpp:210
-
- virtual ::CORBA::Boolean _is_a (
- const char *type_id
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- );
-
- virtual const char* _interface_repository_id (void) const;
- virtual ::CORBA::Boolean marshal (TAO_OutputCDR &cdr);
-
- protected:
- // Abstract or local interface only.
- Codec (void);
-
- virtual ~Codec (void);
-
- private:
- // Private and unimplemented for concrete interfaces.
- Codec (const Codec &);
-
- void operator= (const Codec &);
- };
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- extern TAO_CodecFactory_Export ::CORBA::TypeCode_ptr const _tc_Codec;
-
- // TAO_IDL - Generated from
- // be\be_visitor_typedef/typedef_ch.cpp:379
-
- typedef CORBA::Short EncodingFormat;
- typedef CORBA::Short_out EncodingFormat_out;
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- extern TAO_CodecFactory_Export ::CORBA::TypeCode_ptr const _tc_EncodingFormat;
-
- // TAO_IDL - Generated from
- // be\be_visitor_constant/constant_ch.cpp:52
-
- const IOP::EncodingFormat ENCODING_CDR_ENCAPS = 0;
-
- // TAO_IDL - Generated from
- // be\be_type.cpp:258
-
- struct Encoding;
-
- typedef
- TAO_Fixed_Var_T<
- Encoding
- >
- Encoding_var;
-
- typedef
- Encoding &
- Encoding_out;
-
- // TAO_IDL - Generated from
- // be\be_visitor_structure/structure_ch.cpp:57
-
- struct TAO_CodecFactory_Export Encoding
- {
- typedef Encoding_var _var_type;
-
- static void _tao_any_destructor (void *);
- IOP::EncodingFormat format;
- ::CORBA::Octet major_version;
- ::CORBA::Octet minor_version;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- extern TAO_CodecFactory_Export ::CORBA::TypeCode_ptr const _tc_Encoding;
-
- // TAO_IDL - Generated from
- // be\be_type.cpp:258
-
- struct Encoding_1_2;
-
- typedef
- TAO_Fixed_Var_T<
- Encoding_1_2
- >
- Encoding_1_2_var;
-
- typedef
- Encoding_1_2 &
- Encoding_1_2_out;
-
- // TAO_IDL - Generated from
- // be\be_visitor_structure/structure_ch.cpp:57
-
- struct TAO_CodecFactory_Export Encoding_1_2
- {
- typedef Encoding_1_2_var _var_type;
-
- static void _tao_any_destructor (void *);
- IOP::EncodingFormat format;
- ::CORBA::Octet major_version;
- ::CORBA::Octet minor_version;
- CONV_FRAME::CodeSetId char_codeset;
- CONV_FRAME::CodeSetId wchar_codeset;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- extern TAO_CodecFactory_Export ::CORBA::TypeCode_ptr const _tc_Encoding_1_2;
-
- // TAO_IDL - Generated from
- // be\be_interface.cpp:646
-
-#if !defined (_IOP_CODECFACTORY__VAR_OUT_CH_)
-#define _IOP_CODECFACTORY__VAR_OUT_CH_
-
- class CodecFactory;
- typedef CodecFactory *CodecFactory_ptr;
-
- typedef
- TAO_Objref_Var_T<
- CodecFactory
- >
- CodecFactory_var;
-
- typedef
- TAO_Objref_Out_T<
- CodecFactory
- >
- CodecFactory_out;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_interface/interface_ch.cpp:54
-
-#if !defined (_IOP_CODECFACTORY_CH_)
-#define _IOP_CODECFACTORY_CH_
-
- class TAO_CodecFactory_Export CodecFactory
- : public virtual ::CORBA::Object
- {
- public:
- typedef CodecFactory_ptr _ptr_type;
- typedef CodecFactory_var _var_type;
-
- // The static operations.
- static CodecFactory_ptr _duplicate (CodecFactory_ptr obj);
-
- static void _tao_release (CodecFactory_ptr obj);
-
- static CodecFactory_ptr _narrow (
- ::CORBA::Object_ptr obj
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- );
-
- static CodecFactory_ptr _unchecked_narrow (
- ::CORBA::Object_ptr obj
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- );
-
- static CodecFactory_ptr _nil (void)
- {
- return static_cast<CodecFactory_ptr> (0);
- }
-
-
-
- // TAO_IDL - Generated from
- // be\be_visitor_exception/exception_ch.cpp:53
-
-#if !defined (_IOP_CODECFACTORY_UNKNOWNENCODING_CH_)
-#define _IOP_CODECFACTORY_UNKNOWNENCODING_CH_
-
- class TAO_CodecFactory_Export UnknownEncoding : public ::CORBA::UserException
- {
- public:
-
- UnknownEncoding (void);
- UnknownEncoding (const UnknownEncoding &);
- ~UnknownEncoding (void);
-
- UnknownEncoding &operator= (const UnknownEncoding &);
-
- static void _tao_any_destructor (void *);
-
- static UnknownEncoding *_downcast ( ::CORBA::Exception *);
- static const UnknownEncoding *_downcast ( ::CORBA::Exception const *);
-
- static ::CORBA::Exception *_alloc (void);
-
- virtual ::CORBA::Exception *_tao_duplicate (void) const;
-
- virtual void _raise (void) const;
-
- virtual void _tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const;
-
- virtual void _tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- );
-
- virtual ::CORBA::TypeCode_ptr _tao_type (void) const;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- static ::CORBA::TypeCode_ptr const _tc_UnknownEncoding;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_exception/exception_ch.cpp:53
-
-#if !defined (_IOP_CODECFACTORY_UNSUPPORTEDCODESET_CH_)
-#define _IOP_CODECFACTORY_UNSUPPORTEDCODESET_CH_
-
- class TAO_CodecFactory_Export UnsupportedCodeset : public ::CORBA::UserException
- {
- public:
-
- CONV_FRAME::CodeSetId codeset;
- UnsupportedCodeset (void);
- UnsupportedCodeset (const UnsupportedCodeset &);
- ~UnsupportedCodeset (void);
-
- UnsupportedCodeset &operator= (const UnsupportedCodeset &);
-
- static void _tao_any_destructor (void *);
-
- static UnsupportedCodeset *_downcast ( ::CORBA::Exception *);
- static const UnsupportedCodeset *_downcast ( ::CORBA::Exception const *);
-
- static ::CORBA::Exception *_alloc (void);
-
- virtual ::CORBA::Exception *_tao_duplicate (void) const;
-
- virtual void _raise (void) const;
-
- virtual void _tao_encode (
- TAO_OutputCDR &
- ACE_ENV_ARG_DECL
- ) const;
-
- virtual void _tao_decode (
- TAO_InputCDR &
- ACE_ENV_ARG_DECL
- );
-
- // TAO_IDL - Generated from
- // be\be_visitor_exception/exception_ctor.cpp:66
-
- UnsupportedCodeset (
- CONV_FRAME::CodeSetId _tao_codeset
- );
-
- virtual ::CORBA::TypeCode_ptr _tao_type (void) const;
- };
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- static ::CORBA::TypeCode_ptr const _tc_UnsupportedCodeset;
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_operation/operation_ch.cpp:46
-
- virtual ::IOP::Codec_ptr create_codec (
- const ::IOP::Encoding & enc
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- )
- ACE_THROW_SPEC ((
- ::CORBA::SystemException,
- ::IOP::CodecFactory::UnknownEncoding
- )) = 0;
-
- // TAO_IDL - Generated from
- // be\be_visitor_operation/operation_ch.cpp:46
-
- virtual ::IOP::Codec_ptr create_codec_with_codesets (
- const ::IOP::Encoding_1_2 & enc
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- )
- ACE_THROW_SPEC ((
- ::CORBA::SystemException,
- ::IOP::CodecFactory::UnknownEncoding,
- ::IOP::CodecFactory::UnsupportedCodeset
- )) = 0;
-
- // TAO_IDL - Generated from
- // be\be_visitor_interface/interface_ch.cpp:210
-
- virtual ::CORBA::Boolean _is_a (
- const char *type_id
- ACE_ENV_ARG_DECL_WITH_DEFAULTS
- );
-
- virtual const char* _interface_repository_id (void) const;
- virtual ::CORBA::Boolean marshal (TAO_OutputCDR &cdr);
-
- protected:
- // Abstract or local interface only.
- CodecFactory (void);
-
- virtual ~CodecFactory (void);
-
- private:
- // Private and unimplemented for concrete interfaces.
- CodecFactory (const CodecFactory &);
-
- void operator= (const CodecFactory &);
- };
-
-#endif /* end #if !defined */
-
- // TAO_IDL - Generated from
- // be\be_visitor_typecode/typecode_decl.cpp:49
-
- extern TAO_CodecFactory_Export ::CORBA::TypeCode_ptr const _tc_CodecFactory;
-
-// TAO_IDL - Generated from
-// be\be_visitor_module/module_ch.cpp:78
-
-} // module IOP
-
-// TAO_IDL - Generated from
-// be\be_visitor_traits.cpp:61
-
-// Traits specializations.
-namespace TAO
-{
-
-#if !defined (_IOP_CODEC__TRAITS_)
-#define _IOP_CODEC__TRAITS_
-
- template<>
- struct TAO_CodecFactory_Export Objref_Traits< ::IOP::Codec>
- {
- static ::IOP::Codec_ptr duplicate (
- ::IOP::Codec_ptr
- );
- static void release (
- ::IOP::Codec_ptr
- );
- static ::IOP::Codec_ptr nil (void);
- static ::CORBA::Boolean marshal (
- ::IOP::Codec_ptr p,
- TAO_OutputCDR & cdr
- );
- };
-
-#endif /* end #if !defined */
-
-#if !defined (_IOP_CODECFACTORY__TRAITS_)
-#define _IOP_CODECFACTORY__TRAITS_
-
- template<>
- struct TAO_CodecFactory_Export Objref_Traits< ::IOP::CodecFactory>
- {
- static ::IOP::CodecFactory_ptr duplicate (
- ::IOP::CodecFactory_ptr
- );
- static void release (
- ::IOP::CodecFactory_ptr
- );
- static ::IOP::CodecFactory_ptr nil (void);
- static ::CORBA::Boolean marshal (
- ::IOP::CodecFactory_ptr p,
- TAO_OutputCDR & cdr
- );
- };
-
-#endif /* end #if !defined */
-}
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/any_op_ch.cpp:53
-
-TAO_CodecFactory_Export void operator<<= (::CORBA::Any &, const IOP::Encoding &); // copying version
-TAO_CodecFactory_Export void operator<<= (::CORBA::Any &, IOP::Encoding*); // noncopying version
-TAO_CodecFactory_Export ::CORBA::Boolean operator>>= (const ::CORBA::Any &, IOP::Encoding *&); // deprecated
-TAO_CodecFactory_Export ::CORBA::Boolean operator>>= (const ::CORBA::Any &, const IOP::Encoding *&);
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/any_op_ch.cpp:53
-
-TAO_CodecFactory_Export void operator<<= (::CORBA::Any &, const IOP::Encoding_1_2 &); // copying version
-TAO_CodecFactory_Export void operator<<= (::CORBA::Any &, IOP::Encoding_1_2*); // noncopying version
-TAO_CodecFactory_Export ::CORBA::Boolean operator>>= (const ::CORBA::Any &, IOP::Encoding_1_2 *&); // deprecated
-TAO_CodecFactory_Export ::CORBA::Boolean operator>>= (const ::CORBA::Any &, const IOP::Encoding_1_2 *&);
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/cdr_op_ch.cpp:54
-
-TAO_CodecFactory_Export ::CORBA::Boolean operator<< (TAO_OutputCDR &, const IOP::Encoding &);
-TAO_CodecFactory_Export ::CORBA::Boolean operator>> (TAO_InputCDR &, IOP::Encoding &);
-
-// TAO_IDL - Generated from
-// be\be_visitor_structure/cdr_op_ch.cpp:54
-
-TAO_CodecFactory_Export ::CORBA::Boolean operator<< (TAO_OutputCDR &, const IOP::Encoding_1_2 &);
-TAO_CodecFactory_Export ::CORBA::Boolean operator>> (TAO_InputCDR &, IOP::Encoding_1_2 &);
-
-// TAO_IDL - Generated from
-// be\be_codegen.cpp:1040
-
-TAO_END_VERSIONED_NAMESPACE_DECL
-
-#include /**/ "ace/post.h"
-
-#endif /* ifndef */
diff --git a/TAO/tao/CodecFactory/IOP_CodecS.h b/TAO/tao/CodecFactory/IOP_CodecS.h
deleted file mode 100644
index 17b1360599e..00000000000
--- a/TAO/tao/CodecFactory/IOP_CodecS.h
+++ /dev/null
@@ -1,28 +0,0 @@
-// -*- C++ -*-
-//
-// $Id$
-
-// **** Code generated by the The ACE ORB (TAO) IDL Compiler ****
-// TAO and the TAO IDL Compiler have been developed by:
-// Center for Distributed Object Computing
-// Washington University
-// St. Louis, MO
-// USA
-// http://www.cs.wustl.edu/~schmidt/doc-center.html
-// and
-// Distributed Object Computing Laboratory
-// University of California at Irvine
-// Irvine, CA
-// USA
-// http://doc.ece.uci.edu/
-// and
-// Institute for Software Integrated Systems
-// Vanderbilt University
-// Nashville, TN
-// USA
-// http://www.isis.vanderbilt.edu/
-//
-// Information about TAO is available at:
-// http://www.cs.wustl.edu/~schmidt/TAO.html
-
-// Skeleton file generation suppressed with command line option -SS
diff --git a/TAO/tao/PI_Server/PortableServer_ORBInitializer.cpp b/TAO/tao/PI_Server/PortableServer_ORBInitializer.cpp
index 67a496a2d58..8534d3cbd23 100644
--- a/TAO/tao/PI_Server/PortableServer_ORBInitializer.cpp
+++ b/TAO/tao/PI_Server/PortableServer_ORBInitializer.cpp
@@ -39,6 +39,7 @@ TAO_PortableServer_ORBInitializer::register_policy_factories (
PortableInterceptor::ORBInitInfo_ptr info
ACE_ENV_ARG_DECL)
{
+#if !defined (CORBA_E_MICRO)
// Register the PortableServer policy factories.
PortableInterceptor::PolicyFactory_ptr tmp;
ACE_NEW_THROW_EX (tmp,
@@ -102,6 +103,9 @@ TAO_PortableServer_ORBInitializer::register_policy_factories (
ACE_ENDTRY;
ACE_CHECK;
}
+#else
+ ACE_UNUSED_ARG (info);
+#endif
}
TAO_END_VERSIONED_NAMESPACE_DECL
diff --git a/TAO/tao/PI_Server/PortableServer_PolicyFactory.cpp b/TAO/tao/PI_Server/PortableServer_PolicyFactory.cpp
index 50a2a0a5643..cf31c2d03f4 100644
--- a/TAO/tao/PI_Server/PortableServer_PolicyFactory.cpp
+++ b/TAO/tao/PI_Server/PortableServer_PolicyFactory.cpp
@@ -25,6 +25,7 @@ TAO_PortableServer_PolicyFactory::create_policy (
ACE_THROW_SPEC ((CORBA::SystemException,
CORBA::PolicyError))
{
+#if !defined (CORBA_E_MICRO)
#if (TAO_HAS_MINIMUM_POA == 0)
@@ -112,6 +113,13 @@ TAO_PortableServer_PolicyFactory::create_policy (
ACE_THROW_RETURN (CORBA::PolicyError (CORBA::BAD_POLICY_TYPE),
CORBA::Policy::_nil ());
+#else
+ ACE_UNUSED_ARG (value);
+ ACE_UNUSED_ARG (type);
+
+ ACE_THROW_RETURN (CORBA::PolicyError (CORBA::BAD_POLICY_TYPE),
+ CORBA::Policy::_nil ());
+#endif
}
TAO_END_VERSIONED_NAMESPACE_DECL
diff --git a/TAO/tao/PortableServer/Object_Adapter.cpp b/TAO/tao/PortableServer/Object_Adapter.cpp
index 7cdbd0d6b50..6db68c29c3a 100644
--- a/TAO/tao/PortableServer/Object_Adapter.cpp
+++ b/TAO/tao/PortableServer/Object_Adapter.cpp
@@ -623,8 +623,8 @@ TAO_Object_Adapter::open (ACE_ENV_SINGLE_ARG_DECL)
#else
PortableServer::POAManager_var poa_manager;
PortableServer::POAManager_ptr pm = PortableServer::POAManager::_nil ();
+ PortableServer::POAManagerFactory_ptr fptr = PortableServer::POAManagerFactory::_nil ();
::CORBA::PolicyList policy_list;
- PortableServer::POAManagerFactory_ptr fptr;
ACE_NEW_THROW_EX (pm,
TAO_POA_Manager (*this, 0, policy_list, fptr),
CORBA::NO_MEMORY
diff --git a/TAO/tao/PortableServer/Root_POA.cpp b/TAO/tao/PortableServer/Root_POA.cpp
index 6a88211aab5..945aafd7c2b 100644
--- a/TAO/tao/PortableServer/Root_POA.cpp
+++ b/TAO/tao/PortableServer/Root_POA.cpp
@@ -434,6 +434,7 @@ TAO_Root_POA::create_POA_i (const char *adapter_name,
= root_poa->the_POAManagerFactory ();
CORBA::PolicyList empty_policies;
+
// The POAManager name will be generated when the POAManager instance
// is created.
the_poa_manager
@@ -598,8 +599,8 @@ TAO_Root_POA::find_POA (const char *adapter_name,
#if ! defined (CORBA_E_MICRO)
TAO_Root_POA *
TAO_Root_POA::find_POA_i (const ACE_CString &child_name,
- CORBA::Boolean activate_it
- ACE_ENV_ARG_DECL)
+ CORBA::Boolean activate_it
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
PortableServer::POA::AdapterNonExistent))
{
@@ -607,7 +608,7 @@ TAO_Root_POA::find_POA_i (const ACE_CString &child_name,
int result = this->children_.find (child_name,
child);
-#if (TAO_HAS_MINIMUM_POA == 0)
+#if (TAO_HAS_MINIMUM_POA == 0) && !defined (CORBA_E_COMPACT)
if (result != 0)
{
diff --git a/TAO/tao/RTCORBA/RT_Invocation_Endpoint_Selectors.cpp b/TAO/tao/RTCORBA/RT_Invocation_Endpoint_Selectors.cpp
index 6e712fe4fc9..a850ca0bea8 100644
--- a/TAO/tao/RTCORBA/RT_Invocation_Endpoint_Selectors.cpp
+++ b/TAO/tao/RTCORBA/RT_Invocation_Endpoint_Selectors.cpp
@@ -95,7 +95,7 @@ TAO_RT_Invocation_Endpoint_Selector::select_endpoint_based_on_client_protocol_po
ACE_Time_Value *val
ACE_ENV_ARG_DECL)
{
- CORBA::Boolean valid_profile_found = 0;
+ CORBA::Boolean valid_profile_found = false;
// Even though cycling through all the protocols is the correct
// things to do to find a match, starting from the start of the
@@ -120,11 +120,11 @@ TAO_RT_Invocation_Endpoint_Selector::select_endpoint_based_on_client_protocol_po
if (profile->tag () == client_protocols[protocol_index].protocol_type)
{
- valid_profile_found = 1;
+ valid_profile_found = true;
r.profile (profile);
- int status =
+ int const status =
this->endpoint_from_profile (r,
val
ACE_ENV_ARG_PARAMETER);
diff --git a/TAO/tao/RTCORBA/RT_Transport_Descriptor.cpp b/TAO/tao/RTCORBA/RT_Transport_Descriptor.cpp
index 0058ea2023c..79c86d3d785 100644
--- a/TAO/tao/RTCORBA/RT_Transport_Descriptor.cpp
+++ b/TAO/tao/RTCORBA/RT_Transport_Descriptor.cpp
@@ -80,11 +80,11 @@ TAO_RT_Transport_Descriptor::is_equivalent (const TAO_Transport_Descriptor_Inter
dynamic_cast<const TAO_RT_Transport_Descriptor*> (other_prop);
if (rhs == 0)
- return 0;
+ return false;
// Check if endpoint is equivalent.
if (this->endpoint_->is_equivalent (rhs->endpoint_) == 0)
- return 0;
+ return false;
// Check the property_list_.
TAO_RT_Transport_Descriptor_Property *current =
@@ -95,18 +95,17 @@ TAO_RT_Transport_Descriptor::is_equivalent (const TAO_Transport_Descriptor_Inter
while (current || rhs_current)
{
- if (rhs_current == 0 ||
- current == 0)
- return 0;
+ if (rhs_current == 0 || current == 0)
+ return false;
if (current->is_equivalent (rhs_current) == 0)
- return 0;
+ return false;
current = current->next_;
rhs_current = rhs_current->next_;
}
- return 1;
+ return true;
}
u_long
diff --git a/TAO/TAO_IDL/be/be_codegen.cpp b/TAO/TAO_IDL/be/be_codegen.cpp
index 3b9ecc830f8..ad8f51e61d7 100644
--- a/TAO/TAO_IDL/be/be_codegen.cpp
+++ b/TAO/TAO_IDL/be/be_codegen.cpp
@@ -152,6 +152,27 @@ TAO_CodeGen::start_client_header (const char *fname)
<< "\"\n\n";
}
+ if (be_global->include_guard () != 0)
+ {
+ *this->client_header_ << "#ifndef "
+ << be_global->include_guard ()
+ << "\n";
+
+ *this->client_header_ << "#error "
+ << "You should not include " << fname;
+
+ if (be_global->safe_include () != 0)
+ {
+ *this->client_header_ << ", use " << be_global->safe_include ();
+ }
+
+ *this->client_header_ << "\n";
+
+ *this->client_header_ << "#endif /* "
+ << be_global->include_guard ()
+ << " */\n";
+ }
+
// To get ACE_UNUSED_ARGS
this->gen_standard_include (this->client_header_,
"ace/config-all.h");
@@ -966,11 +987,22 @@ TAO_CodeGen::start_anyop_source (const char *fname)
<< "\"";
}
- // Generate the include statement for the client header. We just
- // need to put only the base names. Path info is not required.
- *this->anyop_source_ << "\n#include \""
- << be_global->be_get_anyop_header_fname (1)
- << "\"";
+ if (be_global->safe_include ())
+ {
+ // Generate the safe include if it is defined instead of the client header
+ // need to put only the base names. Path info is not required.
+ *this->anyop_source_ << "\n#include \""
+ << be_global->safe_include ()
+ << "\"";
+ }
+ else
+ {
+ // Generate the include statement for the client header. We just
+ // need to put only the base names. Path info is not required.
+ *this->anyop_source_ << "\n#include \""
+ << be_global->be_get_anyop_header_fname (1)
+ << "\"";
+ }
this->gen_typecode_includes (this->anyop_source_);
@@ -1605,18 +1637,12 @@ TAO_CodeGen::gen_stub_hdr_includes (void)
this->client_header_
);
- // Not needed at the moment, since UserException.h is pulled in by
- // ORB.h, which is included in the stub header file. May change if
- // ORB.h is rearranged to make a lighter include for applications.
- // System exception throw spec for every operation may change soon.
-#if 0
// For IDL exception, we need full knowledge of CORBA::UserException.
this->gen_cond_file_include (
idl_global->exception_seen_,
"tao/UserException.h",
this->client_header_
);
-#endif /* 0 */
this->gen_standard_include (this->client_header_,
"tao/Environment.h");
@@ -1769,11 +1795,22 @@ TAO_CodeGen::gen_stub_src_includes (void)
<< "\"";
}
- // Generate the include statement for the client header. We just
- // need to put only the base names. Path info is not required.
- *this->client_stubs_ << "\n#include \""
- << be_global->be_get_client_hdr_fname (1)
- << "\"";
+ if (be_global->safe_include ())
+ {
+ // Generate the safe include if it is defined instead of the client header
+ // need to put only the base names. Path info is not required.
+ *this->client_stubs_ << "\n#include \""
+ << be_global->safe_include ()
+ << "\"";
+ }
+ else
+ {
+ // Generate the include statement for the client header. We just
+ // need to put only the base names. Path info is not required.
+ *this->client_stubs_ << "\n#include \""
+ << be_global->be_get_client_hdr_fname (1)
+ << "\"";
+ }
if (be_global->tc_support ()
&& !be_global->gen_anyop_files ())